@@ -5,11 +5,10 @@ import pytest
 from mock import Mock, patch
 
 import vessl
-from openapi_client.api.api_v1_api import APIV1Api
+from openapi_client.api.apiv1_api import APIV1Api
 from openapi_client.models import (
     SignInAPIInput,
     SignInCliConfirmAPIInput,
-    SignUpAPIInput,
 )
 from vessl.util.config import VesslConfigLoader
 from vessl.util.exception import VesslApiException
@@ -79,14 +78,15 @@ def setup_test_account():
             )
         ).token
     except VesslApiException:
-        jwt_token = vessl.vessl_api.sign_up_api(
-            sign_up_api_input=SignUpAPIInput(
-                name=name,
-                username=username,
-                password=password,
-                email=email,
-            )
-        ).token
+        # jwt_token = vessl.vessl_api.sign_up_pending_user_api(
+        #     sign_up_api_input=SignUpPendingUserAPIInput(
+        #         name=name,
+        #         username=username,
+        #         password=password,
+        #         email=email,
+        #     )
+        # ).token
+        pass
 
     # Configure access token
     cli_token = vessl.vessl_api.sign_in_cli_token_api().cli_token
