@@ -1,7 +1,11 @@
+import os
+import tempfile
+
 import pytest
 
 import vessl
 from test.conftest import USE_MOCK
+from vessl.util.file_object import UploadableS3Object
 from vessl.util.random import random_string
 
 
@@ -12,7 +16,22 @@ class TestVolume:
     @pytest.mark.order(index=1)
     def test_create_volume_file(self):
         volume_id = vessl.vessl_api.project.volume_id
-        vessl.create_volume_file(volume_id, False, self.file_name)
+        skeleton = vessl.create_volume_file(volume_id, False, self.file_name)
+
+        # create an actual file on local
+        local_path = os.path.join(tempfile.gettempdir(), self.file_name)
+        with open(local_path, 'w') as f:
+            f.write("dummy")
+
+        UploadableS3Object(
+            local_path,
+            skeleton.upload_url.federation_token.bucket,
+            skeleton.upload_url.federation_token.key,
+            skeleton.upload_url.federation_token.token,
+        ).upload()
+
+        # remove the local file
+        os.remove(local_path)
 
     def test_read_volume_file(self):
         volume_id = vessl.vessl_api.project.volume_id
