@@ -182,8 +182,8 @@ class TensorboardCollector:
         for tag in tags:
             scalars = self._event_accumulator.Scalars(tag)
             self._flush_scalars(tag)  # Flush right away
-            for s in scalars:
-                self._log_scalar(tag, s)
+            for scalar in scalars:
+                self._log_scalar(tag, scalar)
 
     def _flush_scalars(self, tag):
         with self._event_accumulator.scalars._mutex:
@@ -199,8 +199,8 @@ class TensorboardCollector:
         for tag in tags:
             images = self._event_accumulator.Images(tag)
             self._flush_images(tag)  # Flush right away
-            for i in images:
-                self._log_image(tag, i)
+            for image in images:
+                self._log_image(tag, image)
 
     def _flush_images(self, tag):
         with self._event_accumulator.images._mutex:
@@ -225,8 +225,8 @@ class TensorboardCollector:
         for tag in tags:
             audios = self._event_accumulator.Audio(tag)
             self._flush_audios(tag)  # Flush right away
-            for i in audios:
-                self._log_audio(tag, i)
+            for audio in audios:
+                self._log_audio(tag, audio)
 
     def _flush_audios(self, tag):
         with self._event_accumulator.audios._mutex:
@@ -324,6 +324,12 @@ class TensorboardCollector:
                 for tag in tags:
                     self._flush_audios(tag)
 
+    def close(self):
+        """Joins thread to stop collecting. Used by tests."""
+        self._exit.set()
+        self._thread.join()
+        return
+
 
 # Global variable to ensure only one `TensorboardCollector` is active
 tensorboard_collector_instance: Optional[TensorboardCollector] = None
