@@ -2,7 +2,9 @@ import abc
 import os
 import pickle
 import subprocess
-from typing import Any, Dict, List, TypeVar, Union
+import types
+from io import BufferedReader
+from typing import Any, Callable, Dict, List, TypeVar, Union
 
 import cloudpickle
 import uvicorn
@@ -212,6 +214,15 @@ def _save_object(save_type: Union[str, None], obj: Any, path: str) -> str:
     raise VesslRuntimeException("Could not save the object")
 
 
+def _try_load(loader: Callable, br: BufferedReader) -> Any:
+    try:
+        return loader(br)
+    except Exception as e:
+        raise VesslRuntimeException(
+            f"Could not load the object. Did you use a different Python version to register the model?\nError: {e}"
+        )
+
+
 def _load_object(save_type: str, path: str) -> Any:
     """Load the object from given path
 
@@ -229,19 +240,19 @@ def _load_object(save_type: str, path: str) -> Any:
             torch = get_module(
                 "torch", required='torch package is required. Run "pip install torch".'
             )
-            return torch.load(f)
+            return _try_load(torch.load, f)
 
     with open(path, "rb") as f:
         if save_type == "cloudpickle":
-            return cloudpickle.load(f)
+            return _try_load(cloudpickle.load, f)
         if save_type == "joblib":
             joblib = get_module(
                 "joblib",
                 required='joblib package is required. Run "pip install joblib".',
             )
-            return joblib.load(f)
+            return _try_load(joblib.load, f)
         if save_type == "pickle":
-            return pickle.load(f)
+            return _try_load(pickle.load, f)
     raise InvalidParamsError("Unknown save type")
 
 
@@ -528,7 +539,13 @@ def register_torch_model(
         postprocess_data(callable): Function that will postprocess data. Defaults to identity function.
         requirements(list): List of requirements. Defaults to [].
     """
-    # TODO: Check if torch model.
+    # Check if the model is torch
+    torch_nn = get_module(
+        "torch.nn", required='torch package is required. Run "pip install torch".'
+    )
+    if not isinstance(model_instance, torch_nn.Module):
+        raise InvalidParamsError("model_instance must be a torch.nn.Module.")
+
     organization_name = _get_organization_name(**kwargs)
     if requirements is None:
         requirements = []
@@ -580,7 +597,13 @@ def _load_model(install_reqs: bool = False) -> _ModelServer:
         (ModelServer) Model server.
     """
     with open(MANIFEST_FILENAME, "r") as f:
-        manifest = yaml.load(f, Loader=yaml.FullLoader)
+        try:
+            manifest = yaml.load(f, Loader=yaml.FullLoader)
+        except yaml.YAMLError:
+            raise VesslRuntimeException(
+                "Invalid manifest file. Please register the model again."
+            )
+
     _manifest_schema.validate(manifest)
     # Check for requirements
     if install_reqs:
@@ -641,7 +664,7 @@ def _run_model_server(model: _ModelServer, remote: bool):
             print("Result:", result)
             return result
 
-    uvicorn.run(app, port=8000)
+    uvicorn.run(app, host="0.0.0.0", port=8000)
 
 
 def serve_model(
