@@ -8,7 +8,7 @@ from vessl.util.downloader import Downloader
 
 def clone_codes(code_refs: List[ResponseGitHubCodeRef]):
     for code_ref in code_refs:
-        git_url = f"https://{code_ref.token}@github.com/{code_ref.git_owner}/{code_ref.git_repo}.git"
+        git_url = f"https://x-access-token:{code_ref.token}@github.com/{code_ref.git_owner}/{code_ref.git_repo}.git"
         if code_ref.mount_path:
             dirname = code_ref.mount_path
         else:
